@@ -23,10 +23,9 @@ for i in range(861):
     dataOut[i] = int(a[0])
 
 # list of C parameter
-cp = Point([0.000001, 0.00001, 0.0001, 0.001, 0.01, 0.1, 1, 10, 100])
+cp = [0.000001, 0.00001, 0.0001, 0.001, 0.01, 0.1, 1, 10, 100]
 # list of gamma parameter in kernel function
-gamma = Point(
-    [0.000001, 0.00001, 0.0001, 0.001, 0.01, 0.1, 1, 10, 100])
+gamma = [0.000001, 0.00001, 0.0001, 0.001, 0.01, 0.1, 1, 10, 100]
 
 # create the Problem
 Regression = LibSVMClassification(dataIn, dataOut)
